@@ -3,6 +3,10 @@
     Copyright (C) 2008 Omat Holding B.V. <info@omat.nl>
     Copyright (C) 2009 Kevin Ottens <ervin@kde.org>
 
+    Copyright (c) 2010 Klarälvdalens Datakonsult AB,
+                       a KDAB Group company <info@kdab.com>
+    Author: Kevin Ottens <kevin@kdab.com>
+
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
     the Free Software Foundation; either version 2 of the License, or (at your
@@ -22,19 +26,7 @@
 #ifndef __IMAP_RESOURCE_H__
 #define __IMAP_RESOURCE_H__
 
-class KJob;
-
 #include <akonadi/resourcebase.h>
-#include <boost/shared_ptr.hpp>
-#include <QtCore/QStringList>
-
-#include <kimap/fetchjob.h>
-#include <kimap/listjob.h>
-
-namespace KMime
-{
-  class Message;
-}
 
 namespace KIMAP
 {
@@ -43,6 +35,8 @@ namespace KIMAP
 
 class ImapAccount;
 class ImapIdleManager;
+class SessionPool;
+class ResourceState;
 
 class ImapResource : public Akonadi::ResourceBase, public Akonadi::AgentBase::ObserverV2
 {
@@ -55,12 +49,28 @@ public:
   ImapResource( const QString &id );
   ~ImapResource();
 
+
+  int configureDialog( WId windowId );
+  QStringList serverCapabilities() const;
+
 public Q_SLOTS:
   virtual void configure( WId windowId );
-  void requestManualExpunge( qint64 collectionId );
+
+  // DBus methods
+  Q_SCRIPTABLE void requestManualExpunge( qint64 collectionId );
+  Q_SCRIPTABLE void setFastSyncEnabled( bool fastSync );
+  Q_SCRIPTABLE bool isFastSyncEnabled() const;
+  Q_SCRIPTABLE int configureSubscription();
 
 protected Q_SLOTS:
+  void startIdleIfNeeded();
+  void startIdle();
+
+  void abortActivity();
+
   void retrieveCollections();
+  void retrieveCollectionAttributes( const Akonadi::Collection &collection );
+
   void retrieveItems( const Akonadi::Collection &col );
   bool retrieveItem( const Akonadi::Item &item, const QSet<QByteArray> &parts );
 
@@ -71,74 +81,49 @@ protected:
   virtual void itemMoved( const Akonadi::Item &item, const Akonadi::Collection &source,
                           const Akonadi::Collection &destination );
 
+
   virtual void collectionAdded( const Akonadi::Collection &collection, const Akonadi::Collection &parent );
   virtual void collectionChanged( const Akonadi::Collection &collection, const QSet<QByteArray> &parts );
   virtual void collectionRemoved( const Akonadi::Collection &collection );
   virtual void collectionMoved( const Akonadi::Collection &collection, const Akonadi::Collection &source,
                                 const Akonadi::Collection &destination );
 
+
   virtual void doSetOnline(bool online);
 
+
 private Q_SLOTS:
-  void onPasswordRequestCompleted( const QString &password, bool userRejected );
-
-  void onConnectSuccess( KIMAP::Session *session );
-  void onConnectError( KIMAP::Session *session, int code, const QString &message );
-  void onMailBoxesReceived( const QList<KIMAP::MailBoxDescriptor> &descriptors,
-                            const QList< QList<QByteArray> > &flags );
-  void onMailBoxesReceiveDone( KJob *job );
-  void onGetAclDone( KJob *job );
-  void onRightsReceived( KJob *job );
-  void onQuotasReceived( KJob *job );
-  void onGetMetaDataDone( KJob *job );
-  void onSelectDone( KJob *job );
-  void onHeadersReceived( const QString &mailBox, const QMap<qint64, qint64> &uids,
-                          const QMap<qint64, qint64> &sizes, const QMap<qint64, KIMAP::MessageFlags> &flags,
-                          const QMap<qint64, KIMAP::MessagePtr> &messages );
-  void onHeadersFetchDone( KJob *job );
-  void onFlagsReceived( const QString &mailBox, const QMap<qint64, qint64> &uids,
-                        const QMap<qint64, qint64> &sizes, const QMap<qint64, KIMAP::MessageFlags> &flags,
-                        const QMap<qint64, KIMAP::MessagePtr> &messages );
-  void onFlagsFetchDone( KJob *job );
-  void onMessagesReceived( const QString &mailBox, const QMap<qint64, qint64> &uids,
-                           const QMap<qint64, KIMAP::MessagePtr> &messages );
-  void onContentFetchDone( KJob *job );
-  void onCreateMailBoxDone( KJob *job );
-  void onRenameMailBoxDone( KJob *job );
-  void onSetAclDone( KJob *job );
-  void onSetMetaDataDone( KJob *job );
-  void onDeleteMailBoxDone( KJob *job );
-  void onMailBoxMoveDone( KJob *job );
-  void onSubscribeDone( KJob *job );
-  void onAppendMessageDone( KJob *job );
-  void onStoreFlagsDone( KJob *job );
-  void onPreItemMoveSelectDone( KJob *job );
-  void onCopyMessageDone( KJob *job );
-  void onPostItemMoveStoreFlagsDone( KJob *job );
-  void onIdleCollectionFetchDone( KJob *job );
-
-  void startConnect( bool forceManualAuth = false );
   void reconnect();
 
-  void expungeRequested( const QVariant &collectionArgument );
+  void scheduleConnectionAttempt();
+  void startConnect( const QVariant & ); // the parameter is necessary, since this method is used by the task scheduler
+  void onConnectDone( int errorCode, const QString &errorMessage );
+  void onConnectionLost( KIMAP::Session *session );
+
+
+  void onIdleCollectionFetchDone( KJob *job );
+
+
   void onExpungeCollectionFetchDone( KJob *job );
+  void triggerCollectionExpunge( const QVariant &collectionVariant );
+
+
+  void triggerCollectionExtraInfoJobs( const QVariant &collection );
+
+  void taskDestroyed( QObject *task );
 
 private:
-  void triggerNextCollectionChangeJob( const Akonadi::Collection &collection,
-                                       const QStringList &remainingParts );
-  void triggerCollectionExtraInfoJobs( const Akonadi::Collection &collection );
-  void triggerExpunge( const QString &mailBox );
+  friend class ResourceState;
 
-  QString rootRemoteId() const;
-  QString mailBoxForCollection( const Akonadi::Collection &col ) const;
+  void queueTask( QObject *task );
   bool needsNetwork() const;
-  bool isSessionAvailable() const;
-  void startIdle();
 
   friend class ImapIdleManager;
 
-  ImapAccount *m_account;
+  SessionPool *m_pool;
+  QList<QObject*> m_taskList;
   ImapIdleManager *m_idle;
+  bool m_fastSync;
 };
 
 #endif
