@@ -32,13 +32,6 @@
 #include <QLayout>
 #include <QStackedWidget>
 
-
-static bool isBlackListed( const QString &name )
-{
-  static const QSet<QString> blackList = QSet<QString>() << "akonadi" << "file" << "dir" << "net";
-  return blackList.contains( name );
-}
-
 class CompatibilityIntroductionLabel : public QWidget
 {
   public:
@@ -113,12 +106,9 @@ class KResourceCreationWidget : public QWidget
       mainLayout->addWidget( mPageWidget );
 
       mTypes = mFactory->typeNames();
-
-      // Filter-out types for which we have a native akonadi resource
-      foreach( const QString &type, mTypes ) {
-        if ( isBlackListed( type ) )
-          mTypes.removeAll( type );
-      }
+      int index = mTypes.indexOf( QLatin1String( "akonadi" ) );
+      if ( index != -1 )
+        mTypes.removeAt( index );
 
       foreach ( const QString &type, mTypes ) {
         QString description = mFactory->typeDescription( type );
@@ -339,12 +329,12 @@ KResourceAssistant::KResourceAssistant( const QString& resourceFamily, QWidget *
 
   d->mCreationWidget = new KResourceCreationWidget( familyName, d->mFactory, this );
   addPage( d->mCreationWidget, i18nc( "@title assistant dialog step",
-                                      "Step 1: Select a KDE resource plugin") );
+                                      "Step 1: Select a KDE resource plugin" ) );
 
   d->mConfigWidget =
     new KResourceConfigWidget( d->mCreationWidget->mTypes, d->mFactory, this );
   addPage( d->mConfigWidget, i18nc( "@title assistant dialog step",
-                                    "Step 2: Configure the selected KDE resource plugin") );
+                                    "Step 2: Configure the selected KDE resource plugin" ) );
 
   d->mFolderWidget = new KResourceFolderConfigWidget( familyName, this );
   d->mLastPage = addPage( d->mFolderWidget, i18nc( "@title assistant dialog step",
